@@ -6,8 +6,6 @@ class ZeroOrOne(RelationshipManager):
 
     def single(self):
         nodes = super(ZeroOrOne, self).all()
-        if not nodes:
-            return
         if len(nodes) == 1:
             return nodes[0]
         if len(nodes) > 1:
@@ -17,11 +15,12 @@ class ZeroOrOne(RelationshipManager):
         node = self.single()
         return [node] if node else []
 
-    def connect(self, obj):
-        if self.origin.__node__.has_relationship(self.direction, self.relation_type):
-            raise AttemptedCardinalityViolation("Node already has one relationship")
+    def connect(self, obj, properties=None):
+        if len(self):
+            raise AttemptedCardinalityViolation(
+                    "Node already has {0} can't connect more".format(self))
         else:
-            return super(ZeroOrOne, self).connect(obj)
+            return super(ZeroOrOne, self).connect(obj, properties)
 
 
 class OneOrMore(RelationshipManager):
@@ -40,7 +39,7 @@ class OneOrMore(RelationshipManager):
         raise CardinalityViolation(self, 'none')
 
     def disconnect(self, obj):
-        if len(self.origin.__node__.get_related_nodes(self.direction, self.relation_type)) < 2:
+        if super(OneOrMore, self).__len__() < 2:
             raise AttemptedCardinalityViolation("One or more expected")
         return super(OneOrMore, self).disconnect(obj)
 
@@ -62,12 +61,12 @@ class One(RelationshipManager):
         return [self.single()]
 
     def disconnect(self, obj):
-        raise AttemptedCardinalityViolation("Cardinality one, cannot disconnect use rerelate")
+        raise AttemptedCardinalityViolation("Cardinality one, cannot disconnect use reconnect")
 
     def connect(self, obj):
         if not self.origin.__node__:
             raise Exception("Node has not been saved cannot connect!")
-        if self.origin.__node__.has_relationship(self.direction, self.relation_type):
+        if len(self):
             raise AttemptedCardinalityViolation("Node already has one relationship")
         else:
             return super(One, self).connect(obj)
